@@ -2,7 +2,7 @@ from .date_calculations import chronological_decimal_age, corrected_decimal_age,
 from .global_functions import centile, sds_for_measurement, measurement_from_sds, percentage_median_bmi
 from .centile_bands import centile_band_for_centile
 from .bmi_functions import bmi_from_height_weight, weight_for_bmi_height
-from .growth_interpretations import comment_prematurity_correction
+from .age_advice_strings import comment_prematurity_correction
 from .fictional_child import generate_fictional_child_data
 from .dynamic_growth import correlate_weight, create_correlation_surface, create_thrive_lines
 from .uk_who import select_reference_data_for_uk_who_chart
